@@ -6,6 +6,9 @@ import ftplib,string,os
 from ftpy_define import *
 
 class ftpclient:
+	#--------------------------------#
+	#	Member Method                #
+	#--------------------------------#
 	def setHostname(self,hostname):
 		self.hostname = hostname
 	
@@ -51,6 +54,9 @@ class ftpclient:
 	def getLocalDir_Obj(self):
 		return self.localdir_obj
 	
+	#--------------------------------#
+	#	Connection                   #
+	#--------------------------------#
 	#FTP Connection to FTP Server
 	def connect(self):
 		try:
@@ -90,7 +96,61 @@ class ftpclient:
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
+	
+	#Set pasv mode
+	def setPasvmode(self,mode):
+		try:
+			if mode == C_ON:
+				self.return_msg = self.ftpcon.set_pasv(True)
+			else:
+				self.ftpcon.set_pasv(False)
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
 
+	#Get welcome message
+	def getWelcomeMsg(self):
+		try:
+			self.return_msg = self.ftpcon.getwelcome()
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#Get Server System
+	def getServerSystem(self):
+		try:
+			self.sendUserCmd("SYST")
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+	
+	#Get Server Status
+	def getServerStatus(self):
+		try:
+			self.sendUserCmd("STAT")
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#--------------------------------#
+	#	Send  Command                #
+	#--------------------------------#
+	#Send user command
+	def sendUserCmd(self,cmd):
+		try:
+			self.return_msg = self.ftpcon.sendcmd(cmd)
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+			
+	#--------------------------------#
+	#	Remote Directory             #
+	#--------------------------------#
 	#Get remote dir list
 	def getRemoteDirData(self,pattarn=""):
 		try:
@@ -125,6 +185,9 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
+	#--------------------------------#
+	#	File Transfer                #
+	#--------------------------------#
 	#Get file(BINARY MODE)
 	def getRemoteFile(self,remote_filename,local_filename):
 		try:
@@ -148,6 +211,32 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
+	#Get file(ASCII MODE)
+	def getRemoteFileAscii(self,remote_filename,local_filename):
+		try:
+			self.return_msg = self.ftpcon.retrlines("RETR " + remote_filename,open(local_filename,"wb").write)
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			os.remove(local_filename)
+			self.error_obj = e
+			return C_NG
+	
+	#Put file(ASCII MODE)
+	def putLocalFileAscii(self,remote_filename,local_filename):
+		try:
+			localfile = open(local_filename,"rb")
+			self.return_msg = self.ftpcon.storlines("STOR " + remote_filename,localfile)
+			localfile.close()
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#--------------------------------#
+	#	Remote File Control          #
+	#--------------------------------#
 	#Get file size
 	def getRemoteFileSize(self,remote_filename):
 		try:
@@ -156,6 +245,30 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
+	#Remove file
+	def removeRemoteFile(self,remote_filename):
+		try:
+			self.return_msg = self.ftpcon.delete(remote_filename)
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#Chage mode to remote file
+	def changeModeRemoteFile(self,remote_filename,file_mode):
+		try:
+			send_command = "SITE CHMOD %s %s" % (file_mode,remote_filename)
+			self.return_msg = self.ftpcon.sendcmd(send_command)
+			self.getRemoteDirData()
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+
+	#--------------------------------#
+	#	Remote Directory Control     #
+	#--------------------------------#
 	#Create dir
 	def createRemote_dir(self,dir_name):
 		try:
@@ -176,27 +289,6 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
-	#Remove file
-	def removeRemoteFile(self,remote_filename):
-		try:
-			self.return_msg = self.ftpcon.delete(remote_filename)
-			self.getRemoteDirData()
-			return C_OK
-		except Exception, e:
-			self.error_obj = e
-			return C_NG
-	
-	#Chage mode to remote file
-	def changeModeRemoteFile(self,remote_filename,file_mode):
-		try:
-			send_command = "SITE CHMOD %s %s" % (file_mode,remote_filename)
-			self.return_msg = self.ftpcon.sendcmd(send_command)
-			self.getRemoteDirData()
-			return C_OK
-		except Exception, e:
-			self.error_obj = e
-			return C_NG
-
 	#Get Directory
 	def getRemoteDir(self,remote_dir,local_dir):
 		try:
@@ -235,6 +327,9 @@ class ftpclient:
 			return C_NG
 
 
+	#--------------------------------#
+	#	Local Directory Control      #
+	#--------------------------------#
 	#Create local dir
 	def createLocalDir(self,dir_name):
 		try:
@@ -274,6 +369,18 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 	
+	#Delete local directory
+	def deleteLocalDirectory(self,dirname):
+		try:
+			os.rmdir(dirname)
+			return C_OK
+		except Exception, e:
+			self.error_obj = e
+			return C_NG
+			
+	#--------------------------------#
+	#	Local File Control           #
+	#--------------------------------#
 	#Change local file name
 	def renameLocalFile(self,fromname,toname):
 		try:
@@ -292,50 +399,6 @@ class ftpclient:
 			self.error_obj = e
 			return C_NG
 
-	#Delete local directory
-	def deleteLocalDirectory(self,dirname):
-		try:
-			os.rmdir(dirname)
-			return C_OK
-		except Exception, e:
-			self.error_obj = e
-			return C_NG
-
-	#Set pasv mode
-	def setPasvmode(self,mode):
-		try:
-			if mode == C_ON:
-				self.return_msg = self.ftpcon.set_pasv(True)
-			else:
-				self.ftpcon.set_pasv(False)
-			return C_OK
-		except Exception, e:
-			self.error_obj = e
-			return C_NG
-			
-	#Get file(ASCII MODE)
-	def getRemoteFileAscii(self,remote_filename,local_filename):
-		try:
-			self.return_msg = self.ftpcon.retrlines("RETR " + remote_filename,open(local_filename,"wb").write)
-			self.getRemoteDirData()
-			return C_OK
-		except Exception, e:
-			os.remove(local_filename)
-			self.error_obj = e
-			return C_NG
-	
-	#Put file(ASCII MODE)
-	def putLocalFileAscii(self,remote_filename,local_filename):
-		try:
-			localfile = open(local_filename,"rb")
-			self.return_msg = self.ftpcon.storlines("STOR " + remote_filename,localfile)
-			localfile.close()
-			self.getRemoteDirData()
-			return C_OK
-		except Exception, e:
-			self.error_obj = e
-			return C_NG
-
 	#Rename file
 	def renameRemoteFile(self,from_filename,to_filename):
 		try:
@@ -344,6 +407,9 @@ class ftpclient:
 		except Exception, e:
 			self.error_obj = e
 			return C_NG
+
+
+			
 	
 	#Class initial
 	def __init__(self):
