@@ -302,6 +302,8 @@ class ftpgui(Frame):
 		self.printGUI()
 		self.HostVar.set(hostname)
 		self.PortVar.set(portno)
+		if pasv == C_ON:
+			self.PasvVar.set(C_ON)
 		self.ftpclient = ftpclient.ftpclient()
 		self.refreshLocalList()
 		self.connectFlag = C_OFF
@@ -315,7 +317,7 @@ class ftpgui(Frame):
 	#Print FTPy widget
 	def printGUI(self):
 		#Tk
-		self.master.title("FTPy-0.1.4")
+		self.master.title("FTPy-0.2.0")
 		
 		#Frame 
 		frameTop = Frame(self)
@@ -358,7 +360,9 @@ class ftpgui(Frame):
 		menuTop.add_cascade(label="connect",menu=menuConnect)
 		menuConnect.add_command(label="connect",command=self.connect)			
 		menuConnect.add_command(label="disconnect",command=self.disconnect)
+		menuConnect.add_separator()
 		menuConnect.add_command(label="abort",command=self.abort)
+		menuConnect.add_separator()
 		menuConnect.add_command(label="quit",command=self.quit)
 
 	#Menu display
@@ -366,6 +370,11 @@ class ftpgui(Frame):
 		menuDisplay = Menu(menuTop,font="system 10")
 		menuTop.add_cascade(label="display",menu=menuDisplay)
 		menuDisplay.add_command(label="refresh",command=self.refresh)
+		menuDisplay.add_separator()
+		menuDisplay.add_command(label="show server system",command=self.showServerSystem)
+		menuDisplay.add_command(label="show server status",command=self.showServerStatus)
+		menuDisplay.add_command(label="send command",command=self.sendCommand)
+		
 
 	#Menu bookmark
 	def makeMenuBookmark(self,menuTop):
@@ -386,17 +395,19 @@ class ftpgui(Frame):
 		self.menuPopupLocal = Menu(font="system 10")
 		self.menuPopupLocal.add_command(label="Create directory",command=self.createLocalDirectory)
 		self.menuPopupLocal.add_command(label="Delete directory",command=self.deleteLocalDirectory)
-		self.menuPopupLocal.add_command(label="Delete File",command=self.deleteLocalFile)
+		self.menuPopupLocal.add_separator()
 		self.menuPopupLocal.add_command(label="Rename",command=self.renameLocalFile)
+		self.menuPopupLocal.add_command(label="Delete File",command=self.deleteLocalFile)
 		
 	#Popup menu(Remote)
 	def makeMenuPopupRemote(self):
 		self.menuPopupRemote = Menu(font="system 10")
-		self.menuPopupRemote.add_command(label="Change mode",command=self.changeMode)
-		self.menuPopupRemote.add_command(label="Delete directory",command=self.deleteRemoteDirectory)
 		self.menuPopupRemote.add_command(label="Create directory",command=self.createRemoteDirectory)
-		self.menuPopupRemote.add_command(label="Delete File",command=self.deleteRemoteFile)
+		self.menuPopupRemote.add_command(label="Delete directory",command=self.deleteRemoteDirectory)
+		self.menuPopupRemote.add_separator()
+		self.menuPopupRemote.add_command(label="Change mode",command=self.changeMode)
 		self.menuPopupRemote.add_command(label="Rename",command=self.renameRemoteFile)
+		self.menuPopupRemote.add_command(label="Delete File",command=self.deleteRemoteFile)
 
 	#Make host connect infomation widget
 	def makeHostInfoWidget(self,frameTop):
@@ -413,21 +424,21 @@ class ftpgui(Frame):
 		labelPass = Label(frameTop,text="Password",font="system 10")
 		self.entryPass = Entry(frameTop,width="10",bg="white",font="system 10",textvariable=self.PassVar,show="*")
 		self.PasvVar = IntVar()
-		chbtnPasv = Checkbutton(frameTop,text="PASV",font="system 10",variable=self.PasvVar,onvalue=C_ON,offvalue=C_OFF)
+		self.chbtnPasv = Checkbutton(frameTop,text="PASV",font="system 10",variable=self.PasvVar,onvalue=C_ON,offvalue=C_OFF)
 		self.entryHost.bind("<Return>",self.pressEnter); self.entryPort.bind("<Return>",self.pressEnter)
 		self.entryUser.bind("<Return>",self.pressEnter); self.entryPass.bind("<Return>",self.pressEnter)
 		labelHost.grid(row=0,column=1); self.entryHost.grid(row=0,column=2)
 		labelPort.grid(row=0,column=3); self.entryPort.grid(row=0,column=4)
 		labelUser.grid(row=0,column=5); self.entryUser.grid(row=0,column=6)
 		labelPass.grid(row=0,column=7); self.entryPass.grid(row=0,column=8)
-		chbtnPasv.grid(row=0,column=9)
+		self.chbtnPasv.grid(row=0,column=9)
 	
 	#Make button widget(connect,disconnect)
 	def makeConnectButton(self,frameTop):
-		btnConnect = Button(frameTop,bitmap="@connect.xbm",width="24",height="24",command=self.connect)
-		btnDisconnect = Button(frameTop,bitmap="error",width="24",height="24",command=self.disconnect)
-		btnConnect.grid(row=0,column=10)
-		btnDisconnect.grid(row=0,column=11)
+		self.btnConnect = Button(frameTop,bitmap="@connect.xbm",width="24",height="24",command=self.connect)
+		self.btnDisconnect = Button(frameTop,bitmap="error",width="24",height="24",command=self.disconnect)
+		self.btnConnect.grid(row=0,column=10)
+		self.btnDisconnect.grid(row=0,column=11)
 
 	#Make local infomation widget
 	def makeLocalListbox(self,frameLocal):
@@ -451,21 +462,23 @@ class ftpgui(Frame):
 	def makeUpDlButton(self,frameButton):
 		self.btnUpdate = Button(frameButton,text="->",font="system 10",command=self.update)
 		self.btnDownload = Button(frameButton,text="<-",font="system 10",command=self.download)
+		labelDummy = Label(frameButton,height=3)
 		self.btnUpdate.grid(row=0,column=0)
-		self.btnDownload.grid(row=1,column=0)
+		labelDummy.grid(row=1,column=0)
+		self.btnDownload.grid(row=2,column=0)
 
 	#Make remote infomation widget
 	def makeRemoteListbox(self,frameRemote):
 		#Directory path
 		self.RemotePathVar = StringVar(); self.RemotePathVar.set("")
-		entryRemotePath = Entry(frameRemote,bg="white",width=40,font="system 10",textvariable=self.RemotePathVar)
-		entryRemotePath.grid(row=0,column=0,columnspan=2,sticky=W)
+		self.entryRemotePath = Entry(frameRemote,bg="white",width=40,font="system 10",textvariable=self.RemotePathVar)
+		self.entryRemotePath.grid(row=0,column=0,columnspan=2,sticky=W)
 		#Directory list
 		self.listRemote = Listbox(frameRemote,selectmode=EXTENDED,width=40,height=10,bg="white",font="system 10")
 		scrvRemote = Scrollbar(frameRemote,orient=VERTICAL,command=self.listRemote.yview)
 		scrhRemote = Scrollbar(frameRemote,orient=HORIZONTAL,command=self.listRemote.xview)
 		self.listRemote.config(xscrollcommand=scrhRemote.set,yscrollcommand=scrvRemote.set)
-		entryRemotePath.bind("<Return>",self.pressReturnRemote)
+		self.entryRemotePath.bind("<Return>",self.pressReturnRemote)
 		self.listRemote.bind("<Double-Button-1>",self.doubleClickRemote)
 		self.listRemote.bind("<ButtonRelease-3>",self.button3ClickRemote)
 		self.listRemote.grid(row=1,column=0)
@@ -493,22 +506,30 @@ class ftpgui(Frame):
 			self.entryPort.config(state=DISABLED,bg="#d9d9d9")
 			self.entryUser.config(state=DISABLED,bg="#d9d9d9")
 			self.entryPass.config(state=DISABLED,bg="#d9d9d9")
+			self.chbtnPasv.config(state=DISABLED)
 		else:
 			self.entryHost.config(state=NORMAL,bg="white")
 			self.entryPort.config(state=NORMAL,bg="white")
 			self.entryUser.config(state=NORMAL,bg="white")
 			self.entryPass.config(state=NORMAL,bg="white")
+			self.chbtnPasv.config(state=NORMAL)
 	
 	#Lock RemoteInfomation wedget
 	def lockRemoteInfomation(self,lockswitch):
 		if lockswitch == C_ON:
+			self.entryRemotePath.config(state=DISABLED,bg="#d9d9d9")
 			self.listRemote.config(selectmode=BROWSE,bg="#d9d9d9")
 			self.btnUpdate.config(state=DISABLED)
 			self.btnDownload.config(state=DISABLED)
+			self.btnConnect.config(state=DISABLED)
+			self.btnDisconnect.config(state=DISABLED)
 		else:
+			self.entryRemotePath.config(state=NORMAL,bg="white")
 			self.listRemote.config(selectmode=EXTENDED,bg="white")
 			self.btnUpdate.config(state=NORMAL)
 			self.btnDownload.config(state=NORMAL)
+			self.btnConnect.config(state=NORMAL)
+			self.btnDisconnect.config(state=NORMAL)
 
 	#-----------------------------------------#
 	#          Procedure -Message-            #
@@ -528,11 +549,9 @@ class ftpgui(Frame):
 		elif types.InstanceType == type(err_obj):
 			for e in err_obj.args:
 				self.printMessage(C_RED,str(e))
-			self.printMessage(C_BLACK,"\n")
 		else:
 			for e in err_obj:
 				self.printMessage(C_RED,e)
-			self.printMessage(C_BLACK,"\n")
 			
 	
 	#-----------------------------------------#
@@ -645,7 +664,9 @@ class ftpgui(Frame):
 
 	#Disconnect to FTP server
 	def disconnect(self):
-		if self.connectFlag == C_ON:
+		if self.connectFlag <> C_ON:
+			self.printError("Has not connection")
+		else:
 			self.printMessage(C_BLACK,"Disconnect")
 			res = self.ftpclient.close()
 			if res <> C_OK:
@@ -661,6 +682,7 @@ class ftpgui(Frame):
 			else:
 				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
 
+
 	#Abort
 	def abort(self):
 		if self.connectFlag == C_ON:
@@ -670,6 +692,8 @@ class ftpgui(Frame):
 				self.printError(self.ftpclient.getError_Obj())
 				return C_NG
 			self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+		else:
+			self.printError("Has not connection")
 	
 	#FTPy quit
 	def quit(self):
@@ -681,7 +705,9 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#Output version infomation
 	def showVersion(self):
-		tkMessageBox.showinfo(title="Version",message="FTPy\nVersion 0.1.4")
+		wOpenVersion = version()
+		wOpenVersion.init()
+		#tkMessageBox.showinfo(title="Version",message="FTPy\nVersion 0.2.0")
 	
 	#-----------------------------------------#
 	#          Procedure -File Transfe-       #
@@ -713,7 +739,7 @@ class ftpgui(Frame):
 			while self.lockFlag == C_ON:
 				time.sleep(0.5)
 		time.sleep(0.5)
-		self.refresh()
+		self.refreshRemoteList()
 
 	#File download(Remote -> Local)
 	def download(self):
@@ -743,7 +769,7 @@ class ftpgui(Frame):
 				self.printError(self.ftpclient.getError_Obj())
 		while self.lockFlag == C_ON:
 			time.sleep(0.5)
-		self.refresh()
+		self.refreshLocalList()
 			
 	#-----------------------------------------#
 	#          Procedure -Directory-          #
@@ -751,7 +777,7 @@ class ftpgui(Frame):
 	#Refresh dirctory list(Local,Remote)
 	def refresh(self):
 		self.refreshLocalList()
-		if self.lockFlag == C_OFF:
+		if self.lockFlag == C_OFF and self.connectFlag == C_ON:
 			self.refreshRemoteList()
 
 	#Refresh local directory list
@@ -831,6 +857,41 @@ class ftpgui(Frame):
 			if e <> "":
 				line_ent.append(e)
 		return line_ent
+	
+	#Show FTP Server System
+	def showServerSystem(self):
+		if self.connectFlag == C_ON:
+			res = self.ftpclient.getServerSystem()
+			if res == C_OK:
+				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+			else:
+				self.printError(self.ftpclient.getError_Obj())
+		else:
+			self.printError("Has not connection")
+	
+	#Show FTP Server Status
+	def showServerStatus(self):
+		if self.connectFlag == C_ON:
+			res = self.ftpclient.getServerStatus()
+			if res == C_OK:
+				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+			else:
+				self.printError(self.ftpclient.getError_Obj())
+		else:
+			self.printError("Has not connection")
+
+	#Send User Command
+	def sendCommand(self):
+		if self.connectFlag == C_ON:
+			cmd = tkSimpleDialog.askstring("Send Command","User Command")
+			self.printMessage(C_BLACK,cmd)
+			res = self.ftpclient.sendUserCmd(cmd)
+			if res == C_OK:
+				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+			else:
+				self.printError(self.ftpclient.getError_Obj())
+		else:
+			self.printError("Has not connection")
 
 	#-----------------------------------------#
 	#          Procedure -Remote Control-     #
@@ -859,16 +920,20 @@ class ftpgui(Frame):
 
 	#Create directory(Remote)
 	def createRemoteDirectory(self):
-		dirname = tkSimpleDialog.askstring("Create Directory","Directory Name")
-		if dirname <> None:
-			self.printMessage(C_BLACK,"MKD "+dirname)
-			res = self.ftpclient.createRemote_dir(dirname)
-			if res == C_OK:
-				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
-				self.refreshRemoteList()
-			else:
-				self.printError(self.ftpclient.getError_Obj())
-				return C_NG
+		if self.connectFlag == C_ON:
+			dirname = tkSimpleDialog.askstring("Create Directory","Directory Name")
+			if dirname <> None:
+				self.printMessage(C_BLACK,"MKD "+dirname)
+				res = self.ftpclient.createRemote_dir(dirname)
+				if res == C_OK:
+					self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+					self.refreshRemoteList()
+				else:
+					self.printError(self.ftpclient.getError_Obj())
+					return C_NG
+		else:
+			self.printError("Has not connection")
+
 	#Delete Remote directory
 	def deleteRemoteDirectory(self):
 		#Get select item
@@ -889,6 +954,9 @@ class ftpgui(Frame):
 					self.printError(self.ftpclient.getError_Obj())
 					return C_NG
 				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+			else:
+				objname = item[string.rfind(item," ")+1:]
+				self.printError(objname+" is not directory")
 
 				
 	#Delete remote file
@@ -912,6 +980,9 @@ class ftpgui(Frame):
 					return C_NG
 				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
 				self.refreshRemoteList()
+			else:
+				objname = item[string.rfind(item," ")+1:]
+				self.printError(objname+" is not file")
 			
 
 	#Rename remote file,object
@@ -942,7 +1013,7 @@ class ftpgui(Frame):
 	def createLocalDirectory(self):
 		dirname = tkSimpleDialog.askstring("Create Directory","Directory Name")
 		if dirname <> None:
-			self.printMessage(C_BLACK,"mkdir(" + dirname + ")")
+			self.printMessage(C_BLACK,"mkdir "+dirname)
 			res = self.ftpclient.createLocalDir(dirname)
 			if res == C_OK:
 				self.printMessage(C_BLUE,"OK")
@@ -963,7 +1034,7 @@ class ftpgui(Frame):
 			#Check item
 			if item[0] == "d":	#Dirctory
 				dirname = item[string.rfind(item," ")+1:]
-				self.printMessage(C_BLACK,"rmdir(" + dirname + ")")
+				self.printMessage(C_BLACK,"rmdir "+dirname)
 				#Delete Directory
 				res = self.ftpclient.deleteLocalDirectory(dirname)
 				if res <> C_OK:
@@ -971,6 +1042,9 @@ class ftpgui(Frame):
 					return C_NG
 				self.printMessage(C_BLUE,"OK")
 				self.refreshLocalList()
+			else:
+				objname = item[string.rfind(item," ")+1:]
+				self.printError(objname+" is not directory")
 				
 	#Delete file(Local)
 	def deleteLocalFile(self):
@@ -985,14 +1059,18 @@ class ftpgui(Frame):
 			#Check item
 			if item[0] == "-":	#File
 				filename = item[string.rfind(item," ")+1:]
-				self.printMessage(C_BLACK,"rm(" + filename + ")")
+				self.printMessage(C_BLACK,"rm "+filename)
 				#Delete file
 				res = self.ftpclient.deleteLocalFile(filename)
 				if res <> C_OK:
-					self.printError(self.ftpclient.getError_Obj())
+					SELF.PrintError(self.ftpclient.getError_Obj())
 					return C_NG
 				self.printMessage(C_BLUE,"OK")
 				self.refreshLocalList()
+			else:
+				objname = item[string.rfind(item," ")+1:]
+				self.printError(objname+" is not file")
+
 			
 
 	#Rename file,object(Local)
@@ -1007,7 +1085,7 @@ class ftpgui(Frame):
 			fromname = item[string.rfind(item," ")+1:]
 			toname = tkSimpleDialog.askstring("Rename","To filename")
 			if toname <> None:
-				self.printMessage(C_BLACK,"rename(" + fromname + " -> " + toname + ")")
+				self.printMessage(C_BLACK,"mv "+fromname+" "+toname)
 				res = self.ftpclient.renameLocalFile(fromname,toname)
 				if res <> C_OK:
 					self.printError(self.ftpclient.getError_Obj())
@@ -1020,7 +1098,7 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#Press Return event(Remote)
 	def pressReturnRemote(self,event):
-		if self.connectFlag == C_ON:
+		if self.lockFlag == C_OFF and self.connectFlag == C_ON:
 			self.printMessage(C_BLACK,"CWD "+self.RemotePathVar.get())
 			res = self.ftpclient.changeRemoteDir(self.RemotePathVar.get())
 			if res == C_OK:
@@ -1028,6 +1106,8 @@ class ftpgui(Frame):
 				self.refreshRemoteList()
 			else:
 				self.printError(self.ftpclient.getError_Obj())
+		else:
+			self.printError("Has not connection")
 
 	#Double click event(Remote)
 	def doubleClickRemote(self,event):
@@ -1062,7 +1142,7 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#Press Return event(Local)
 	def pressReturnLocal(self,event):
-		self.printMessage(C_BLACK,"lcd(" + self.LocalPathVar.get() + ")")
+		self.printMessage(C_BLACK,"lcd "+self.LocalPathVar.get())
 		res = self.ftpclient.changeLocalDir(self.LocalPathVar.get())
 		if res == C_OK:
 			self.printMessage(C_BLUE,"OK")
@@ -1081,7 +1161,7 @@ class ftpgui(Frame):
 		#Check item
 		if item[0] == "d":	#Directory
 			dirname = item[string.rfind(item," ")+1:]
-			self.printMessage(C_BLACK,"lcd(" + dirname + ")")
+			self.printMessage(C_BLACK,"lcd "+dirname)
 			#Change local directory
 			res = self.ftpclient.changeLocalDir(dirname)
 			if res <> C_OK:
@@ -1113,8 +1193,11 @@ class ftpgui(Frame):
 			user = self.UserVar.get()
 			passwd = self.PassVar.get()
 			pasv = self.PasvVar.get()
-			item = host + ":" + port + ":" + user + ":" + passwd + ":" + str(pasv) + "\n"
-			fileBookmark.write(item)
+			if host <> "":
+				item = host + ":" + port + ":" + user + ":" + passwd + ":" + str(pasv) + "\n"
+				fileBookmark.write(item)
+			else:
+				self.printError("Please input hostname")
 			fileBookmark.close()
 		except Exception, e:
 			self.printError(e)
@@ -1135,6 +1218,45 @@ class ftpgui(Frame):
 		
 
 	
+###############################################
+#	Version class
+###############################################
+class version(Toplevel):
+
+	#Class initial
+	def init(self):
+		master=None
+		Toplevel.__init__(self,master)
+		self.printVersion()
+		self.grab_set()
+
+	#Print bookmark
+	def printVersion(self):
+		self.title("Version")
+		frameMain = Frame(self)
+		textVersion = Text(frameMain,bg="#d9d9d9",font="system 10",height=5,width=60,state=DISABLED)
+		btnOK = Button(frameMain,text="OK",font="system 10",command=self.pushOK)
+
+		frameMain.grid(row=0,column=0)
+		textVersion.grid(row=1,column=0)
+		btnOK.grid(row=2,column=0)
+
+		msg = [
+		"FTPy\n\n",
+		"Version 0.2.0\n",
+		"Copyright(c) 2002 Shinkichi <shinkichi@user.sourceforge.jp>\n"
+		"http://ftpy.sourceforge.jp/"
+		]
+		textVersion.config(state=NORMAL)
+		for e in msg:
+			textVersion.insert(END,e)
+		textVersion.config(state=DISABLED)
+
+	#Pushed OK Button
+	def pushOK(self):
+		self.destroy()
+
+
 ###############################################
 #	Bookmark class
 ###############################################
